<h1 align="center">
	Mando
	<br />
	<img
		width="150"
		alt="Mandalorian"
		src="https://raw.githubusercontent.com/samarthdave/mando/master/mando.png">
</h1>

<blockquote>
  Hey Mando! You spilled my drink...
</blockquote>

![npm](https://img.shields.io/npm/v/mando)

<hr />

#### Resources
- [Mandalorian Emoji](https://www.starwars.com/news/the-mandalorian-and-the-child-coming-to-disney-emoji-blitz)
